=======
Credits
=======

Development Lead
----------------

* `Moritz E. Beber <morbeb@biosustain.dtu.dk>`_

Contributors
------------

* `Christian Lieven <clie@biosustain.dtu.dk>`_
* `Nikolaus Sonnenschein <niso@biosustain.dtu.dk>`_
